# psdist

Analysis tools for phase space distributions.


## Installation

Install from cloned repository:

```shell
git clone https://github.com/austin-hoover/psdist.git
cd psdist
pip install -e .
```


## Examples

See `/examples` folder.


## Related packages

* https://github.com/openPMD/openPMD-viewer
* https://github.com/bwheelz36/ParticlePhaseSpace
* https://github.com/ColwynGulliford/distgen
* https://aplpy.readthedocs.io/en/stable/fitsfigure/slicing.html
